@@ -20,8 +20,7 @@ sub steps {
 sub _step {
   my ($self, $id, $offset, $len) = (shift, shift, shift, shift);
 
-  $self->{args}[$id]
-    = [@_ ? defined $len ? splice @_, $offset, $len : splice @_, $offset : ()];
+  $self->{args}[$id] = [@_ ? defined $len ? splice @_, $offset, $len : splice @_, $offset : ()];
   return $self if $self->{fail} || --$self->{pending} || $self->{lock};
   local $self->{lock} = 1;
   my @args = map {@$_} @{delete $self->{args}};
@@ -35,8 +34,7 @@ sub _step {
     }
   }
 
-  ($self->{steps} = []) and return $self->resolve(@args)
-    unless $self->{counter};
+  ($self->{steps} = []) and return $self->resolve(@args) unless $self->{counter};
   $self->ioloop->next_tick($self->begin) unless $self->{pending};
   return $self;
 }
@@ -92,9 +90,8 @@ Mojo::IOLoop::Delay - Promises/A+ and flow-control helpers
 
 =head1 DESCRIPTION
 
-L<Mojo::IOLoop::Delay> adds flow-control helpers to L<Mojo::Promise>, which can
-help you avoid deep nested closures that often result from continuation-passing
-style.
+L<Mojo::IOLoop::Delay> adds flow-control helpers to L<Mojo::Promise>, which can help you avoid deep nested closures
+that often result from continuation-passing style.
 
   use Mojo::IOLoop;
 
@@ -118,10 +115,9 @@ style.
 
   Mojo::IOLoop->start;
 
-The idea behind L<Mojo::IOLoop::Delay> is to turn the nested closures above into
-a flat series of closures. In the example below, the call to L</"begin"> creates
-a code reference that we can pass to L<Mojo::IOLoop/"timer"> as a callback, and
-that leads to the next closure in the series when executed.
+The idea behind L<Mojo::IOLoop::Delay> is to turn the nested closures above into a flat series of closures. In the
+example below, the call to L</"begin"> creates a code reference that we can pass to L<Mojo::IOLoop/"timer"> as a
+callback, and that leads to the next closure in the series when executed.
 
   use Mojo::IOLoop;
 
@@ -148,11 +144,9 @@ that leads to the next closure in the series when executed.
   );
   $delay->wait;
 
-Another positive side effect of this pattern is that we do not need to call
-L<Mojo::IOLoop/"start"> and L<Mojo::IOLoop/"stop"> manually, because we know
-exactly when our chain of L</"steps"> has reached the end. So
-L<Mojo::Promise/"wait"> can stop the event loop automatically if it had to be
-started at all in the first place.
+Another positive side effect of this pattern is that we do not need to call L<Mojo::IOLoop/"start"> and
+L<Mojo::IOLoop/"stop"> manually, because we know exactly when our chain of L</"steps"> has reached the end. So
+L<Mojo::Promise/"wait"> can stop the event loop automatically if it had to be started at all in the first place.
 
 =head1 ATTRIBUTES
 
@@ -160,8 +154,7 @@ L<Mojo::IOLoop::Delay> inherits all attributes from L<Mojo::Promise>.
 
 =head1 METHODS
 
-L<Mojo::IOLoop::Delay> inherits all methods from L<Mojo::Promise> and implements
-the following new ones.
+L<Mojo::IOLoop::Delay> inherits all methods from L<Mojo::Promise> and implements the following new ones.
 
 =head2 begin
 
@@ -169,11 +162,9 @@ the following new ones.
   my $cb = $delay->begin($offset);
   my $cb = $delay->begin($offset, $len);
 
-Indicate an active event by incrementing the event counter, the returned
-code reference can be used as a callback, and needs to be executed when the
-event has completed to decrement the event counter again. When all code
-references generated by this method have been executed and the event counter has
-reached zero, L</"steps"> will continue.
+Indicate an active event by incrementing the event counter, the returned code reference can be used as a callback, and
+needs to be executed when the event has completed to decrement the event counter again. When all code references
+generated by this method have been executed and the event counter has reached zero, L</"steps"> will continue.
 
   # Capture all arguments except for the first one (invocant)
   my $delay = Mojo::IOLoop->delay(sub {
@@ -183,9 +174,8 @@ reached zero, L</"steps"> will continue.
   Mojo::IOLoop->client({port => 3000} => $delay->begin);
   $delay->wait;
 
-Arguments passed to the returned code reference are spliced with the given
-offset and length, defaulting to an offset of C<1> with no default length. The
-arguments are then combined in the same order L</"begin"> was called, and passed
+Arguments passed to the returned code reference are spliced with the given offset and length, defaulting to an offset
+of C<1> with no default length. The arguments are then combined in the same order L</"begin"> was called, and passed
 together to the next step.
 
   # Capture all arguments
@@ -227,13 +217,11 @@ Shortcut for passing values between L</"steps">.
 
   $delay = $delay->steps(sub {...}, sub {...});
 
-Sequentialize multiple events, every time the event counter reaches zero a
-callback will run, the first one automatically runs during the next reactor tick
-unless it is delayed by incrementing the event counter. This chain will continue
-until there are no remaining callbacks, a callback does not increment the event
-counter or an exception gets thrown in a callback. Finishing the chain will also
-result in the promise being fulfilled, or if an exception got thrown it will be
-rejected.
+Sequentialize multiple events, every time the event counter reaches zero a callback will run, the first one
+automatically runs during the next reactor tick unless it is delayed by incrementing the event counter. This chain will
+continue until there are no remaining callbacks, a callback does not increment the event counter or an exception gets
+thrown in a callback. Finishing the chain will also result in the promise being fulfilled, or if an exception got
+thrown it will be rejected.
 
 =head1 SEE ALSO
 
