@@ -39,10 +39,7 @@ sub append {
 
 sub debug { 1 >= $LEVEL{$_[0]->level} ? _log(@_, 'debug') : $_[0] }
 
-sub context {
-  my ($self, $str) = @_;
-  return $self->new(parent => $self, context => $str, level => $self->level);
-}
+sub context { $_[0]->new(parent => $_[0], context => $_[1], level => $_[0]->level) }
 
 sub error { 4 >= $LEVEL{$_[0]->level} ? _log(@_, 'error') : $_[0] }
 sub fatal { 5 >= $LEVEL{$_[0]->level} ? _log(@_, 'fatal') : $_[0] }
