@@ -1,12 +1,10 @@
 package PluginWithTemplate;
 use Mojo::Base 'Mojolicious::Plugin';
 
-# "Good news, everyone! I've taught the toaster to feel love!"
 sub register {
   my ($self, $app) = @_;
   push @{$app->renderer->classes}, __PACKAGE__;
-  $app->routes->route('/plugin_with_template')
-    ->to(cb => sub { shift->render('plugin_with_template') });
+  $app->routes->route('/plugin_with_template')->to(cb => sub { shift->render('plugin_with_template') });
 }
 
 1;
